@@ -20,6 +20,7 @@ my %collect_dispatch = (
   '%' => \&collect_percent,
   '.' => \&collect_period,
   '^' => \&collect_ptr,
+  "'" => \&collect_tick,
 );
 
 sub collect_dnso_nodes {
@@ -98,4 +99,9 @@ sub collect_ptr {
   push @{$records->{$parts[0]}{'^'}}, $parts[1] ;
 }
 
+sub collect_tick {
+  my @parts = @_;
+  push @{$records->{$parts[0]}{"'"}}, $parts[1];
+}
+
 1;
